## ProbNum Contributors

The following people contributed to the ProbNum repository.

**Maintainers:** Main developers responsible for ProbNum and the management of the development process.

<div class="authorlist">
	<center>
		<ul>
			<li>
				<a href="https://github.com/jonathanwenger">
					<img class="avatar" alt="jonathanwenger" src="https://github.com/jonathanwenger.png?v=3&s=96" width="64" height="64" />
					<p>Jonathan Wenger</p>
				</a>
			</li>
			<li>
				<a href="https://github.com/pnkraemer">
					<img class="avatar" alt="pnkraemer" src="https://github.com/pnkraemer.png?v=3&s=96" width="64" height="64" />
					<p>Nicholas Krämer</p>
				</a>
			</li>
			<li>
				<a href="https://github.com/nathanaelbosch">
					<img class="avatar" alt="nathanaelbosch" src="https://github.com/nathanaelbosch.png?v=3&s=96" width="64" height="64" />
					<p>Nathanael Bosch</p>
				</a>
			</li>
		</ul>
	</center>
</div>
<div style="clear: both"></div>

---

**Code Contributors:** Developers who made substantial additions to ProbNum's codebase or infrastructure.


<div class="authorlist">
	<center>
		<ul>
			<li>
				<a href="https://github.com/ninaeffenberger">
					<img class="avatar" alt="ninaeffenberger" src="https://github.com/ninaeffenberger.png?v=3&s=96" width="64" height="64" />
					<p>Nina Effenberger</p>
				</a>
			</li>
			<li>
				<a href="https://github.com/alpiges">
					<img class="avatar" alt="alpiges" src="https://github.com/alpiges.png?v=3&s=96" width="64" height="64" />
					<p>Alexandra Gessner</p>
				</a>
			</li>
			<li>
				<a href="https://github.com/coldfix">
					<img class="avatar" alt="coldfix" src="https://github.com/coldfix.png?v=3&s=96" width="64" height="64" />
					<p>Thomas Gläßle</p>
				</a>
			</li>
			<li>
				<a href="https://github.com/tskarvone">
					<img class="avatar" alt="tskarvone" src="https://github.com/tskarvone.png?v=3&s=96" width="64" height="64" />
					<p>Toni Karvonen</p>
				</a>
			</li>	
			<li>
				<a href="https://github.com/marvinpfoertner">
					<img class="avatar" alt="marvinpfoertner" src="https://github.com/marvinpfoertner.png?v=3&s=96" width="64" height="64" />
					<p>Marvin Pförtner</p>
				</a>
			</li>
			<li>
				<a href="https://github.com/schmidtjonathan">
					<img class="avatar" alt="schmidtjonathan" src="https://github.com/schmidtjonathan.png?v=3&s=96" width="64" height="64" />
					<p>Jonathan Schmidt</p>
				</a>
			</li>
			<li>
				<a href="https://github.com/jzenn">
					<img class="avatar" alt="jzenn" src="https://github.com/jzenn.png?v=3&s=96" width="64" height="64" />
					<p>Johannes Zenn</p>
				</a>
			</li>
		</ul>
	</center>
</div>
<div style="clear: both"></div>

---

**Feedback and Other:** People who give valuable feedback and input on the scientific direction or perform code reviews.

<div>
	<a href="https://github.com/philipphennig">
		<img class="avatar" alt="philipphennig" src="https://github.com/philipphennig.png?v=3&s=96" width="28" height="28" />
		Philipp Hennig
	</a>
	<a href="https://github.com/mmahsereci">
		<img class="avatar" alt="mmahsereci" src="https://github.com/mmahsereci.png?v=3&s=96" width="28" height="28" />
		Maren Mahsereci
	</a>
	<a href="https://github.com/ltatzel">
		<img class="avatar" alt="ltatzel" src="https://github.com/ltatzel.png?v=3&s=96" width="28" height="28" />
		Lukas Tatzel
	</a>
</div>

---

If you feel like you have made substantial contributions to ProbNum, contact the maintainers of the package. Your name
will then be added here.
